@@ -27,16 +27,22 @@
 
 """
 
-from mingus.containers import *
+import mingus.containers.Note as Note
+import mingus.containers.NoteContainer as NoteContainer
+import mingus.containers.Bar as Bar
+import mingus.containers.Track as Track
+import mingus.containers.Composition as Composition
+from mingus.containers.Instrument import MidiInstrument
 import mingus.core.notes as notes
-from sys import argv
 import binascii
 
 
 def MIDI_to_Composition(file):
-	"""Converts a MIDI file to a mingus.containers.Composition. \
-This function can raise all kinds of exceptions (IOError, HeaderError, \
-TimeDivisionError, FormatError), so be sure to try and catch."""
+	"""Converts a MIDI file to a mingus.containers.Composition and \
+returns it in a tuple with the last used tempo in beats per minute (this \
+will change in the future). This function can raise all kinds of exceptions \
+(IOError, HeaderError, TimeDivisionError, FormatError), so be sure to try \
+and catch. """
 	m = MidiFile()
 	return m.MIDI_to_Composition(file)
 
@@ -61,15 +67,14 @@ class MidiFile():
 			print "Don't know how to parse this yet"
 			return c
 
-		print header
+		ticks_per_beat = header[2]["ticks_per_beat"]
 		for track in track_data:
 			t = Track()
-			i = MidiInstrument()
 			b = Bar()
 			metronome = 1 # Tick once every quarter note
 			thirtyseconds = 8 # 8 thirtyseconds in a quarter note
-			ticks_per_beat = header[2]["ticks_per_beat"]
 			meter = (4,4)
+			key = 'C'
 
 
 			for e in track:
@@ -78,15 +83,13 @@ class MidiFile():
 				duration =  float(deltatime) / (ticks_per_beat * 4.0)
 				if duration != 0.0:
 					duration = 1.0 / duration
-				print duration
 
 				if deltatime != 0:
 					if not b.place_notes(NoteContainer(), duration):
 						t + b
-						b = Bar()
-						b.set_meter(meter)
+						b = Bar(key, meter)
 						b.place_notes(NoteContainer(), duration)
-					
+						
 
 				# note off
 				if event["event"] == 8:
@@ -96,14 +99,27 @@ class MidiFile():
 				# note on 
 				elif event["event"] == 9:
 					n = Note(notes.int_to_note(event["param1"] % 12), 
-						event["param1"] / 12)
-					n.dynamics["velocity"] = event["param2"]
+						event["param1"] / 12 - 1)
+					n.channel = event["channel"]
+					n.velocity = event["param2"]
 
 					if len(b.bar) > 0:
 						b.bar[-1][2] + n
 					else:
 						b + n
 
+				# note aftertouch
+				elif event["event"] == 10:
+					pass
+				# controller select
+				elif event["event"] == 11:
+					pass
+				# program change
+				elif event["event"] == 12:
+					i = MidiInstrument()
+					i.instrument_nr = event["param1"]
+					t.instrument = i
+
 				# meta event
 				elif event["event"] == 15:
 
@@ -123,7 +139,8 @@ class MidiFile():
 					elif event["meta_event"] == 47:
 						pass
 
-					# Set tempo
+					# Set tempo 
+					#warning Only the last change in bpm will get saved currently
 					elif event["meta_event"] == 81:
 						mpqn = self.bytes_to_int(event["data"])
 						bpm = 60000000 / mpqn
@@ -142,10 +159,16 @@ class MidiFile():
 					elif event["meta_event"] == 89:
 						pass
 
-			t.instrument = i
+					else:
+						print "Unsupported META event", event["meta_event"]
+
+				else:
+					print "Unsupported MIDI event", event["event"]
+
 			t + b
-			c + t
-		return c
+			c.tracks.append(t)
+		
+		return c, bpm
 
 
 
@@ -331,9 +354,9 @@ the MIDI format, the number of tracks and the time division-, the parsed track d
 			return (result, bytes_read)
 	
 if __name__ == "__main__":
+	from sys import argv
 	import fluidsynth
 	import MidiFileOut
 	fluidsynth.init()
-	m = MIDI_to_Composition(argv[1])
-	print m
-	MidiFileOut.write_Composition("test.mid", range(len(m.tracks)), m)
+	m, bpm = MIDI_to_Composition(argv[1])
+	MidiFileOut.write_Composition("test.mid", m, bpm)
